
import { Injectable } from '@angular/core';
import { HttpClient, HttpParams } from '@angular/common/http';
import { Observable, throwError } from 'rxjs';
import { catchError, map } from 'rxjs/operators';
import { ConfigService } from '@services/config.service';

@Injectable({
  providedIn: 'root'
})
export class DataService {
  baseUrl: string;
  private apiUrl: string;

  constructor(private http: HttpClient, private configService: ConfigService) {
    this.baseUrl = this.configService.apiUrl;
    this.apiUrl = `${this.baseUrl}/pxe-templates?page=1&itemsPerPage=1000`;
  }

  getPxeTemplates(filters: { [key: string]: string }): Observable<any[]> {
    const params = new HttpParams({ fromObject: filters });

    return this.http.get<any>(this.apiUrl, { params }).pipe(
      map(response => {
        if (response['hydra:member'] && Array.isArray(response['hydra:member'])) {
          return response['hydra:member'];
        } else {
          throw new Error('Unexpected response format');
        }
      }),
      catchError(error => {
        console.error('Error fetching pxe templates', error);
        return throwError(error);
      })
    );
  }
}
