import {Component, Inject, OnInit} from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {ToastrService} from "ngx-toastr";
import {Router} from "@angular/router";
import {ConfigService} from "@services/config.service";
import {FormBuilder, FormGroup} from "@angular/forms";

@Component({
  selector: 'app-edit-image',
  templateUrl: './edit-image.component.html',
  styleUrl: './edit-image.component.css'
})
export class EditImageComponent implements OnInit{
  baseUrl: string;
  loading: boolean = true;
  imageForm: FormGroup;

  constructor(
    private http: HttpClient,
    public dialogRef: MatDialogRef<EditImageComponent>,
    private fb: FormBuilder,
    private toastService: ToastrService,
    private router: Router,
    private configService: ConfigService,
    @Inject(MAT_DIALOG_DATA) public data: { image: any }
  ) {
    this.baseUrl = this.configService.apiUrl;
    this.imageForm = this.fb.group({
      description: ['']
    })
  }

  ngOnInit(): void {
    this.loading = true;
    this.load()
  }

  load() {
    this.http.get<any>(`${this.baseUrl}${this.data.image['@id']}`).subscribe({
      next: (response) => {
        this.imageForm.patchValue({
          description: response.description
        });
        this.loading = false;
      },
      error: error => {
        this.toastService.error(error.error['hydra:description']);
      }
    });
  }

  save() {
    const payload = this.imageForm.value;

    this.http.put<any>(`${this.baseUrl}${this.data.image['@id']}`, payload).subscribe({
      next: (response) => {
        this.toastService.success('Image updated successfully');
        this.dialogRef.close(true);
      },
      error: error => {
        this.toastService.error(error.error['hydra:description']);
      }
    });
  }

  close() {
    this.dialogRef.close();
  }
}
