import {Component, EventEmitter, Inject, OnInit, Output} from '@angular/core';
import {HttpClient} from "@angular/common/http";
import {MAT_DIALOG_DATA, MatDialogRef} from "@angular/material/dialog";
import {ToastrService} from "ngx-toastr";
import {Router} from "@angular/router";
import {ConfigService} from "@services/config.service";

@Component({
  selector: 'app-rename-image',
  templateUrl: './rename-image.component.html',
  styleUrl: './rename-image.component.css'
})
export class RenameImageComponent implements OnInit{
  baseUrl: string;
  loading: boolean = true;
  name: string = '';
  @Output() eventEmitter = new EventEmitter();

  constructor(
    private http: HttpClient,
    public dialogRef: MatDialogRef<RenameImageComponent>,
    private toastService: ToastrService,
    private router: Router,
    private configService: ConfigService,
    @Inject(MAT_DIALOG_DATA) public data: { imageImageRepository: any }
  ) {
    this.baseUrl = this.configService.apiUrl;
  }

  ngOnInit(): void {
    this.loading = true;
  }

  save() {
    this.http.post<any>(`${this.baseUrl}${this.data.imageImageRepository['@id']}/rename-image`, {
      newName: this.name
    }).subscribe({
      next: (response) => {
        this.toastService.success('Imagen renombrada correctamente');
        this.dialogRef.close(true);
      },
      error: error => {
        this.toastService.error(error.error['hydra:description']);
      }
    });
  }

  close() {
    this.dialogRef.close();
  }
}
